Index: components/policy/core/common/policy_map.h |
diff --git a/components/policy/core/common/policy_map.h b/components/policy/core/common/policy_map.h |
index 7d0d06b80b4ba35e13154726b2dabd17d7e86a43..8ff480a71c2102652b2692f18d66943f20adaf93 100644 |
--- a/components/policy/core/common/policy_map.h |
+++ b/components/policy/core/common/policy_map.h |
@@ -28,6 +28,9 @@ class POLICY_EXPORT PolicyMap { |
base::Value* value; |
ExternalDataFetcher* external_data_fetcher; |
+ // For debugging and displaying only. Set by provider delivering the policy. |
+ PolicySource source; |
+ |
Entry(); |
// Deletes all members owned by |this|. |
@@ -63,6 +66,7 @@ class POLICY_EXPORT PolicyMap { |
void Set(const std::string& policy, |
PolicyLevel level, |
PolicyScope scope, |
+ PolicySource source, |
base::Value* value, |
ExternalDataFetcher* external_data_fetcher); |
@@ -85,11 +89,12 @@ class POLICY_EXPORT PolicyMap { |
void MergeFrom(const PolicyMap& other); |
// Loads the values in |policies| into this PolicyMap. All policies loaded |
// will have |level| and |scope| in their entries. Existing entries are |
// replaced. |
void LoadFrom(const base::DictionaryValue* policies, |
PolicyLevel level, |
- PolicyScope scope); |
+ PolicyScope scope, |
+ PolicySource source); |
// Compares this value map against |other| and stores all key names that have |
// different values or reference different external data in |differing_keys|. |
@@ -85,11 +89,12 @@ class POLICY_EXPORT PolicyMap { |
void MergeFrom(const PolicyMap& other); |
// Loads the values in |policies| into this PolicyMap. All policies loaded |
- // will have |level| and |scope| in their entries. Existing entries are |
- // replaced. |
+ // will have |level|, |scope| and |source| in their entries. Existing entries |
+ // are replaced. |
void LoadFrom(const base::DictionaryValue* policies, |
PolicyLevel level, |